@@ -877,7 +877,7 @@ Static Void bootwrite()
 }  /* bootwrite */
 
 
-void main(argc, argv)
+main(argc, argv)
 int argc;
 Char *argv[];
 {  /* Read in sequences or frequencies and bootstrap or jackknife them */
